@@ -17,13 +17,13 @@
 #'   Arguments may be used in conjunction with one another.
 #' @param variables ([`tidy-select`][dplyr::dplyr_tidy_select])\cr
 #'   columns to include in summaries. Default is `everything()`.
-#' @param denominator (`data.frame`, `integer`)\cr
-#'   Specify this *optional* argument to change the denominator,
-#'   e.g. the `"N"` statistic. Default is `NULL`. See below for details.
+#' @param denominator (`string`, `data.frame`, `integer`)\cr
+#'   Specify this argument to change the denominator,
+#'   e.g. the `"N"` statistic. Default is `'column'`. See below for details.
 #' @param statistic ([`formula-list-selector`][syntax])\cr
 #'   a named list, a list of formulas,
-#'   or a single formula where the list element one or more of  `c("n", "N", "p")`
-#'   (or the RHS of a formula).
+#'   or a single formula where the list element one or more of  `c("n", "N", "p", "n_cum", "p_cum")`
+#'   (on the RHS of a formula).
 #' @param stat_label ([`formula-list-selector`][syntax])\cr
 #'   a named list, a list of formulas, or a single formula where
 #'   the list element is either a named list or a list of formulas defining the
@@ -45,18 +45,27 @@
 #' In such cases, use the `denominator` argument to specify a new definition
 #' of `"N"`, and subsequently `"p"`.
 #' The argument expects one of the following inputs:
+#' - a string: one of `"column"`, `"row"`, or `"cell"`.
+#'     - `"column"`, the default, returns percentages where the sum is equal to
+#'        one within the variable after the data frame has been subset with `by`/`strata`.
+#'     - `"row"` gives 'row' percentages where `by`/`strata` columns are the 'top'
+#'        of a cross table, and the variables are the rows. This is well-defined
+#'        for a single `by` or `strata` variable, and care must be taken when there
+#'        are more to ensure the the results are as you expect.
+#'   - `"cell"` gives percentages where the denominator is the number of non-missing
+#'        rows in the source data frame.
 #' - a data frame. Any columns in the data frame that overlap with the `by`/`strata`
 #'   columns will be used to calculate the new `"N"`.
 #' - an integer. This single integer will be used as the new `"N"`
-#' - a string: one of `"column"`, `"row"`, or `"cell"`. `"column"` is equivalent
-#'   to `denominator=NULL`. `"row"` gives 'row' percentages where `by`/`strata`
-#'   columns are the 'top' of a cross table, and the variables are the rows.
-#'   `"cell"` gives percentages where the denominator is the number of non-missing
-#'   rows in the source data frame.
 #' - a structured data frame. The data frame will include columns from `by`/`strata`.
 #'   The last column must be named `"...ard_N..."`. The integers in this column will
 #'   be used as the updated `"N"` in the calculations.
 #'
+#' Lastly, when the `p` statistic is returned, the proportion is returned---bounded by `[0, 1]`.
+#' However, the default function to format the statistic scales the proportion by 100
+#' and the percentage is returned which matches the default statistic label of `'%'`.
+#' To get the formatted values, pass the ARD to `apply_fmt_fun()`.
+#'
 #' @section Other Statistics:
 #' In some cases, you may need other kinds of statistics for categorical variables.
 #' Despite the name, `ard_continuous()` can be used to obtain these statistics.
@@ -104,13 +113,24 @@ ard_categorical.data.frame <- function(data,
                                        by = dplyr::group_vars(data),
                                        strata = NULL,
                                        statistic = everything() ~ c("n", "p", "N"),
-                                       denominator = NULL,
-                                       fmt_fn = NULL,
+                                       denominator = "column",
+                                       fmt_fun = NULL,
                                        stat_label = everything() ~ default_stat_labels(),
+                                       fmt_fn = deprecated(),
                                        ...) {
   set_cli_abort_call()
   check_dots_used()
 
+  # deprecated args ------------------------------------------------------------
+  if (lifecycle::is_present(fmt_fn)) {
+    lifecycle::deprecate_soft(
+      when = "0.6.1",
+      what = "ard_categorical(fmt_fn)",
+      with = "ard_categorical(fmt_fun)"
+    )
+    fmt_fun <- fmt_fn
+  }
+
   # check inputs ---------------------------------------------------------------
   check_not_missing(variables)
   .check_no_ard_columns(data)
@@ -129,7 +149,7 @@ ard_categorical.data.frame <- function(data,
     data[variables],
     statistic = statistic,
     stat_label = stat_label,
-    fmt_fn = fmt_fn
+    fmt_fun = fmt_fun
   )
   fill_formula_selectors(
     data[variables],
@@ -137,8 +157,8 @@ ard_categorical.data.frame <- function(data,
   )
   check_list_elements(
     x = statistic,
-    predicate = \(x) is.character(x) && all(x %in% c("n", "p", "N")),
-    error_msg = "Elements passed in the {.arg statistic} argument must be one or more of {.val {c('n', 'p', 'N')}}"
+    predicate = \(x) is.character(x) && all(x %in% c("n", "p", "N", "n_cum", "p_cum")),
+    error_msg = "Elements passed in the {.arg statistic} argument must be one or more of {.val {c('n', 'p', 'N', 'n_cum', 'p_cum')}}"
   )
 
   # return empty ARD if no variables selected ----------------------------------
@@ -172,14 +192,14 @@ ard_categorical.data.frame <- function(data,
     )
 
 
-  # final processing of fmt_fn -------------------------------------------------
+  # final processing of fmt_fun ------------------------------------------------
   df_result_final <-
     df_result_tabulation |>
     .process_nested_list_as_df(
-      arg = fmt_fn,
-      new_column = "fmt_fn"
+      arg = fmt_fun,
+      new_column = "fmt_fun"
     ) |>
-    .default_fmt_fn()
+    .default_fmt_fun()
 
   # final processing of stat labels --------------------------------------------
   df_result_final <-
@@ -201,6 +221,7 @@ ard_categorical.data.frame <- function(data,
   df_result_final |>
     dplyr::mutate(context = "categorical") |>
     tidy_ard_column_order() |>
+    tidy_ard_row_order() |>
     as_card()
 }
 
@@ -246,7 +267,7 @@ ard_categorical.data.frame <- function(data,
         imap(
           statistics_tabulation,
           function(x, variable) {
-            if (any(c("N", "p") %in% x[["tabulation"]])) {
+            if (any(c("N", "p", "p_cum") %in% x[["tabulation"]])) {
               TRUE
             } else {
               NULL
@@ -281,7 +302,7 @@ ard_categorical.data.frame <- function(data,
               ))
             }
         }
-        if ("p" %in% tab_stats[["tabulation"]]) {
+        if (any(c("p", "p_cum") %in% tab_stats[["tabulation"]])) {
           df_result_tabulation <-
             df_result_tabulation |>
             dplyr::mutate(
@@ -289,14 +310,24 @@ ard_categorical.data.frame <- function(data,
             )
         }
 
+        df_result_tabulation <-
+          .add_cum_count_stats(
+            df_result_tabulation,
+            variable = variable,
+            by = by,
+            strata = strata,
+            denominator = denominator,
+            tab_stats = tab_stats
+          )
+
         df_result_tabulation |>
           .nesting_rename_ard_columns(variable = variable, by = by, strata = strata) |>
           dplyr::mutate(
-            across(any_of(c("...ard_n...", "...ard_N...", "...ard_p...")), as.list),
+            across(any_of(c("...ard_n...", "...ard_N...", "...ard_p...", "...ard_n_cum...", "...ard_p_cum...")), as.list),
             across(c(matches("^group[0-9]+_level$"), any_of("variable_level")), as.list)
           ) |>
           tidyr::pivot_longer(
-            cols = any_of(c("...ard_n...", "...ard_N...", "...ard_p...")),
+            cols = any_of(c("...ard_n...", "...ard_N...", "...ard_p...", "...ard_n_cum...", "...ard_p_cum...")),
             names_to = "stat_name",
             values_to = "stat"
           ) |>
@@ -333,6 +364,52 @@ ard_categorical.data.frame <- function(data,
   )
 }
 
+
+
+.add_cum_count_stats <- function(x, variable, by, strata, denominator, tab_stats) {
+  # if no cumulative stats were requested, return the object
+  if (!any(c("p_cum", "n_cum") %in% tab_stats[["tabulation"]])) {
+    return(x)
+  }
+
+  # to return cumulative stats, the denominator must be 'column' or 'row'
+  if (!is_string(denominator) || !denominator %in% c("column", "row")) {
+    cli::cli_abort(
+      "The {.arg denominator} argument must be one of {.val {c(\"column\", \"row\")}}
+       when cumulative statistics {.val n_cum} or {.val p_cum} are specified, which
+       were requested for variable {.var {variable}}.",
+      call = get_cli_abort_call()
+    )
+  }
+
+  # calculate the cumulative statistics
+  if (denominator %in% "column") {
+    x <- x |>
+      dplyr::mutate(
+        .by = any_of(c(by, strata)),
+        ...ard_n_cum... = switch("n_cum" %in% tab_stats[["tabulation"]],
+          cumsum(.data$...ard_n...)
+        ),
+        ...ard_p_cum... = switch("p_cum" %in% tab_stats[["tabulation"]],
+          cumsum(.data$...ard_p...)
+        )
+      )
+  } else if (denominator %in% "row") {
+    x <- x |>
+      dplyr::mutate(
+        .by = any_of(variable),
+        ...ard_n_cum... = switch("n_cum" %in% tab_stats[["tabulation"]],
+          cumsum(.data$...ard_n...)
+        ),
+        ...ard_p_cum... = switch("p_cum" %in% tab_stats[["tabulation"]],
+          cumsum(.data$...ard_p...)
+        )
+      )
+  }
+
+  x
+}
+
 #' Results from `table()` as Data Frame
 #'
 #' Takes the results from [table()] and returns them as a data frame.
@@ -410,11 +487,12 @@ ard_categorical.data.frame <- function(data,
     }
 
     df_table <-
-      dplyr::right_join(
+      dplyr::left_join(
+        df_original_strata |> dplyr::arrange(across(all_of(strata))),
         df_table,
-        df_original_strata,
         by = strata
-      )
+      ) |>
+      dplyr::select(all_of(names(df_table)))
   }
 
   df_table
