@@ -1,6 +1,5 @@
 #' Complex ARD Summaries
 #'
-#' `r lifecycle::badge('experimental')`\cr
 #' Function is similar to [ard_continuous()], but allows for more complex
 #' summaries. While `ard_continuous(statistic)` only allows for a univariable
 #' function, `ard_complex(statistic)` can handle more complex data summaries.
@@ -15,6 +14,7 @@
 #'   - `full_data`: the full data frame
 #'   - `by`: character vector of the `by` variables
 #'   - `strata`: character vector of the `strata` variables
+#'
 #'   It is unlikely any one function will need _all_ of the above elements,
 #'   and it's recommended the function passed accepts `...` so that any unused
 #'   arguments will be properly ignored. The `...` also allows this function
@@ -64,12 +64,23 @@ ard_complex.data.frame <- function(data,
                                    by = dplyr::group_vars(data),
                                    strata = NULL,
                                    statistic,
-                                   fmt_fn = NULL,
+                                   fmt_fun = NULL,
                                    stat_label = everything() ~ default_stat_labels(),
+                                   fmt_fn = deprecated(),
                                    ...) {
   set_cli_abort_call()
   check_dots_used()
 
+  # deprecated args ------------------------------------------------------------
+  if (lifecycle::is_present(fmt_fn)) {
+    lifecycle::deprecate_soft(
+      when = "0.6.1",
+      what = "ard_continuous(fmt_fn)",
+      with = "ard_continuous(fmt_fun)"
+    )
+    fmt_fun <- fmt_fn
+  }
+
   # check inputs ---------------------------------------------------------------
   check_not_missing(variables)
   check_not_missing(statistic)
@@ -78,6 +89,11 @@ ard_complex.data.frame <- function(data,
   process_selectors(data, variables = {{ variables }})
   process_formula_selectors(data[variables], statistic = statistic, allow_empty = FALSE)
 
+  # return empty ARD if no variables selected ----------------------------------
+  if (is_empty(variables)) {
+    return(dplyr::tibble() |> as_card())
+  }
+
   missing_statistics_vars <- setdiff(variables, names(statistic))
   if (!is_empty(missing_statistics_vars)) {
     "The following columns do not have {.arg statistic} defined: {.val {missing_statistics_vars}}." |>
@@ -108,7 +124,7 @@ ard_complex.data.frame <- function(data,
     by = {{ by }},
     strata = {{ strata }},
     statistic = statistic,
-    fmt_fn = fmt_fn,
+    fmt_fun = fmt_fun,
     stat_label = stat_label
   ) |>
     dplyr::mutate(context = "complex")
