@@ -31,12 +31,12 @@ test_that("ard_continuous() works", {
 })
 
 
-test_that("ard_continuous(fmt_fn) argument works", {
+test_that("ard_continuous(fmt_fun) argument works", {
   ard_continuous(
     ADSL,
     variables = "AGE",
     statistic = list(AGE = continuous_summary_fns(c("N", "mean", "median"))),
-    fmt_fn =
+    fmt_fun =
       list(
         AGE =
           list(
@@ -46,7 +46,7 @@ test_that("ard_continuous(fmt_fn) argument works", {
           )
       )
   ) |>
-    apply_fmt_fn() |>
+    apply_fmt_fun() |>
     dplyr::select(variable, stat_name, stat, stat_fmt) |>
     as.data.frame() |>
     expect_snapshot()
@@ -55,7 +55,7 @@ test_that("ard_continuous(fmt_fn) argument works", {
     ADSL,
     variables = c("AGE", "BMIBL"),
     statistic = ~ continuous_summary_fns("mean"),
-    fmt_fn =
+    fmt_fun =
       list(
         AGE =
           list(
@@ -63,7 +63,7 @@ test_that("ard_continuous(fmt_fn) argument works", {
           )
       )
   ) |>
-    apply_fmt_fn() |>
+    apply_fmt_fun() |>
     dplyr::select(variable, stat_name, stat, stat_fmt) |>
     as.data.frame() |>
     expect_snapshot()
@@ -73,9 +73,9 @@ test_that("ard_continuous(fmt_fn) argument works", {
     ADSL,
     variables = c("AGE", "BMIBL"),
     statistic = ~ continuous_summary_fns(c("mean", "sd")),
-    fmt_fn = ~ list(~ function(x) round(x, 4))
+    fmt_fun = ~ list(~ function(x) round(x, 4))
   ) |>
-    apply_fmt_fn() |>
+    apply_fmt_fun() |>
     dplyr::select(variable, stat_name, stat, stat_fmt) |>
     as.data.frame() |>
     expect_snapshot()
@@ -178,7 +178,7 @@ test_that("ard_continuous() and ARD column names", {
   ard_colnames <- c(
     "group1", "group1_level", "variable", "variable_level",
     "context", "stat_name", "stat_label", "statistic",
-    "fmt_fn", "warning", "error"
+    "fmt_fun", "warning", "error"
   )
 
   # no errors when these variables are the summary vars
@@ -439,3 +439,34 @@ test_that("ard_continuous() errors with incomplete factor columns", {
       )
   )
 })
+
+
+test_that("ard_continuous() with `as_cards_fn()` inputs", {
+  ttest_works <-
+    as_cards_fn(
+      \(x) t.test(x)[c("statistic", "p.value")],
+      stat_names = c("statistic", "p.value")
+    )
+  ttest_error <-
+    as_cards_fn(
+      \(x) {
+        t.test(x)[c("statistic", "p.value")]
+        stop("Intentional Error")
+      },
+      stat_names = c("statistic", "p.value")
+    )
+
+  # the result is the same when there is no error
+  expect_equal(
+    ard_continuous(mtcars, variables = mpg, statistic = ~ list(ttest = ttest_works)),
+    ard_continuous(mtcars, variables = mpg, statistic = ~ list(ttest = \(x) t.test(x)[c("statistic", "p.value")]))
+  )
+
+  # when there is an error, we get the same structure back
+  expect_equal(
+    ard_continuous(mtcars, variables = mpg, statistic = ~ list(ttest = ttest_error)) |>
+      dplyr::pull("stat_name"),
+    ard_continuous(mtcars, variables = mpg, statistic = ~ list(ttest = \(x) t.test(x)[c("statistic", "p.value")])) |>
+      dplyr::pull("stat_name")
+  )
+})
