@@ -23,6 +23,7 @@ test_that("ARD helpers messaging", {
 })
 
 test_that("bind_ard() .order argument works", {
+  withr::local_options(list(width = 120))
   withr::local_seed(1123)
   expect_snapshot(
     bind_ard(
@@ -32,7 +33,7 @@ test_that("bind_ard() .order argument works", {
       .order = TRUE
     ) |>
       as.data.frame() |>
-      dplyr::select(-c(context, fmt_fn, warning, error))
+      dplyr::select(-c(context, fmt_fun, warning, error))
   )
 
   expect_snapshot(
@@ -43,7 +44,7 @@ test_that("bind_ard() .order argument works", {
       .order = FALSE
     ) |>
       as.data.frame() |>
-      dplyr::select(-c(context, fmt_fn, warning, error))
+      dplyr::select(-c(context, fmt_fun, warning, error))
   )
 })
 
